Use python
==========

The data processing are done by using python functions.

Average images
--------------

To average several diffraction images to be one image, use

.. autofunction:: pdfstream.cli.average

Azimuthal integration
---------------------

To integrate the diffraction image in azimuthal direction, use

.. autofunction:: pdfstream.cli.integrate

Instrumental Calibration
------------------------

To calibrate the instrumental effect on calibration, use

.. autofunction:: pdfstream.cli.instrucalib

Visualization
-------------

To visualize a single data file, use

.. autofunction:: pdfstream.cli.visualize

To visualize several data files, use

.. autofunction:: pdfstream.cli.waterfall


Modeling
--------

The tools to model the PDFs are inside `pdfstream.modeling`.

.. automodule:: pdfstream.modeling
